# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: apexnova/market/market_service.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'apexnova/market/market_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from apexnova.market import market_pb2 as apexnova_dot_market_dot_market__pb2
from apexnova.stub import authorization_context_pb2 as apexnova_dot_stub_dot_authorization__context__pb2
from apexnova.stub import response_pb2 as apexnova_dot_stub_dot_response__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$apexnova/market/market_service.proto\x12\x06market\x1a\x1c\x61pexnova/market/market.proto\x1a)apexnova/stub/authorization_context.proto\x1a\x1c\x61pexnova/stub/response.proto\"X\n\x10ReadStockRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x34\n\x15\x61uthorization_context\x18\x02 \x01(\x0b\x32\x15.AuthorizationContext\"_\n\x11ReadStockResponse\x12\x1c\n\x05stock\x18\x01 \x01(\x0b\x32\r.market.Stock\x12,\n\x11standard_response\x18\x02 \x01(\x0b\x32\x11.StandardResponse\"f\n\x10ReadQuoteRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x02 \x01(\t\x12\x34\n\x15\x61uthorization_context\x18\x03 \x01(\x0b\x32\x15.AuthorizationContext\"c\n\x11ReadQuoteResponse\x12 \n\x05quote\x18\x01 \x01(\x0b\x32\x11.market.QuoteInfo\x12,\n\x11standard_response\x18\x02 \x01(\x0b\x32\x11.StandardResponse\"\xa3\x01\n\x17StreamStatementsRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x13\n\x0b\x66iscal_year\x18\x02 \x01(\x05\x12\x0e\n\x06period\x18\x03 \x01(\t\x12\x0e\n\x06\x63ursor\x18\x04 \x01(\t\x12\r\n\x05limit\x18\x05 \x01(\x05\x12\x34\n\x15\x61uthorization_context\x18\x06 \x01(\x0b\x32\x15.AuthorizationContext\"\x7f\n\x1d\x42\x61lanceSheetStatementResponse\x12\x30\n\tstatement\x18\x01 \x01(\x0b\x32\x1d.market.BalanceSheetStatement\x12,\n\x11standard_response\x18\x02 \x01(\x0b\x32\x11.StandardResponse\"w\n\x19\x43\x61shflowStatementResponse\x12,\n\tstatement\x18\x01 \x01(\x0b\x32\x19.market.CashflowStatement\x12,\n\x11standard_response\x18\x02 \x01(\x0b\x32\x11.StandardResponse\"s\n\x17IncomeStatementResponse\x12*\n\tstatement\x18\x01 \x01(\x0b\x32\x17.market.IncomeStatement\x12,\n\x11standard_response\x18\x02 \x01(\x0b\x32\x11.StandardResponse\"p\n\"FreeCashFlowGrowthScreenerResponse\x12\x1c\n\x05stock\x18\x01 \x01(\x0b\x32\r.market.Stock\x12,\n\x11standard_response\x18\x02 \x01(\x0b\x32\x11.StandardResponse\"\xe1\x01\n!FreeCashFlowGrowthScreenerRequest\x12\x1c\n\x14market_cap_more_than\x18\x01 \x01(\x01\x12\x1d\n\x15market_cap_lower_than\x18\x02 \x01(\x01\x12\'\n\x08\x65xchange\x18\x03 \x01(\x0e\x32\x15.market.StockExchange\x12 \n\x07\x63ountry\x18\x04 \x01(\x0e\x32\x0f.market.Country\x12\x34\n\x15\x61uthorization_context\x18\x05 \x01(\x0b\x32\x15.AuthorizationContext2\xb3\x04\n\x0cStockService\x12@\n\tReadStock\x12\x18.market.ReadStockRequest\x1a\x19.market.ReadStockResponse\x12@\n\tReadQuote\x12\x18.market.ReadQuoteRequest\x1a\x19.market.ReadQuoteResponse\x12h\n\x1cStreamBalanceSheetStatements\x12\x1f.market.StreamStatementsRequest\x1a%.market.BalanceSheetStatementResponse0\x01\x12`\n\x18StreamCashflowStatements\x12\x1f.market.StreamStatementsRequest\x1a!.market.CashflowStatementResponse0\x01\x12\\\n\x16StreamIncomeStatements\x12\x1f.market.StreamStatementsRequest\x1a\x1f.market.IncomeStatementResponse0\x01\x12u\n\x1a\x46reeCashFlowGrowthScreener\x12).market.FreeCashFlowGrowthScreenerRequest\x1a*.market.FreeCashFlowGrowthScreenerResponse0\x01\x42*\n\x13\x63om.apexnova.marketB\x11StockServiceProtoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'apexnova.market.market_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.apexnova.marketB\021StockServiceProtoP\001'
  _globals['_READSTOCKREQUEST']._serialized_start=151
  _globals['_READSTOCKREQUEST']._serialized_end=239
  _globals['_READSTOCKRESPONSE']._serialized_start=241
  _globals['_READSTOCKRESPONSE']._serialized_end=336
  _globals['_READQUOTEREQUEST']._serialized_start=338
  _globals['_READQUOTEREQUEST']._serialized_end=440
  _globals['_READQUOTERESPONSE']._serialized_start=442
  _globals['_READQUOTERESPONSE']._serialized_end=541
  _globals['_STREAMSTATEMENTSREQUEST']._serialized_start=544
  _globals['_STREAMSTATEMENTSREQUEST']._serialized_end=707
  _globals['_BALANCESHEETSTATEMENTRESPONSE']._serialized_start=709
  _globals['_BALANCESHEETSTATEMENTRESPONSE']._serialized_end=836
  _globals['_CASHFLOWSTATEMENTRESPONSE']._serialized_start=838
  _globals['_CASHFLOWSTATEMENTRESPONSE']._serialized_end=957
  _globals['_INCOMESTATEMENTRESPONSE']._serialized_start=959
  _globals['_INCOMESTATEMENTRESPONSE']._serialized_end=1074
  _globals['_FREECASHFLOWGROWTHSCREENERRESPONSE']._serialized_start=1076
  _globals['_FREECASHFLOWGROWTHSCREENERRESPONSE']._serialized_end=1188
  _globals['_FREECASHFLOWGROWTHSCREENERREQUEST']._serialized_start=1191
  _globals['_FREECASHFLOWGROWTHSCREENERREQUEST']._serialized_end=1416
  _globals['_STOCKSERVICE']._serialized_start=1419
  _globals['_STOCKSERVICE']._serialized_end=1982
# @@protoc_insertion_point(module_scope)
