# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: apexnova/identity/account/account_service.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'apexnova/identity/account/account_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from apexnova.identity.account import account_pb2 as apexnova_dot_identity_dot_account_dot_account__pb2
from apexnova.stub import authorization_context_pb2 as apexnova_dot_stub_dot_authorization__context__pb2
from apexnova.stub import response_pb2 as apexnova_dot_stub_dot_response__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/apexnova/identity/account/account_service.proto\x12\x08identity\x1a\'apexnova/identity/account/account.proto\x1a)apexnova/stub/authorization_context.proto\x1a\x1c\x61pexnova/stub/response.proto\"V\n\x12ReadAccountRequest\x12\x34\n\x15\x61uthorization_context\x18\x01 \x01(\x0b\x32\x15.AuthorizationContext\x12\n\n\x02id\x18\x02 \x01(\t\"g\n\x13ReadAccountResponse\x12\"\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x11.identity.Account\x12,\n\x11standard_response\x18\x02 \x01(\x0b\x32\x11.StandardResponse\"\x9f\x02\n\x14\x43reateAccountRequest\x12\x34\n\x15\x61uthorization_context\x18\x01 \x01(\x0b\x32\x15.AuthorizationContext\x12\x12\n\nowner_name\x18\x02 \x01(\t\x12\x1a\n\x12preferred_username\x18\x03 \x01(\t\x12\x10\n\x08password\x18\x04 \x01(\t\x12\r\n\x05phone\x18\x05 \x01(\t\x12\x13\n\x0bpicture_url\x18\x06 \x01(\t\x12+\n\x0c\x61\x63\x63ount_type\x18\x07 \x01(\x0e\x32\x15.identity.AccountType\x12/\n\x0e\x61\x63\x63ount_status\x18\x08 \x01(\x0e\x32\x17.identity.AccountStatus\x12\r\n\x05\x65mail\x18\t \x01(\t\"\x80\x01\n\x15\x43reateAccountResponse\x12\"\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x11.identity.Account\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\x12,\n\x11standard_response\x18\x03 \x01(\x0b\x32\x11.StandardResponse\"\xfd\x01\n\x14UpdateAccountRequest\x12\x34\n\x15\x61uthorization_context\x18\x01 \x01(\x0b\x32\x15.AuthorizationContext\x12\n\n\x02id\x18\x02 \x01(\t\x12\x12\n\nowner_name\x18\x03 \x01(\t\x12\r\n\x05phone\x18\x05 \x01(\t\x12\x13\n\x0bpicture_url\x18\x06 \x01(\t\x12+\n\x0c\x61\x63\x63ount_type\x18\x07 \x01(\x0e\x32\x15.identity.AccountType\x12/\n\x0e\x61\x63\x63ount_status\x18\x08 \x01(\x0e\x32\x17.identity.AccountStatus\x12\r\n\x05\x65mail\x18\t \x01(\t\"i\n\x15UpdateAccountResponse\x12\"\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x11.identity.Account\x12,\n\x11standard_response\x18\x02 \x01(\x0b\x32\x11.StandardResponse\"X\n\x14\x44\x65leteAccountRequest\x12\x34\n\x15\x61uthorization_context\x18\x01 \x01(\x0b\x32\x15.AuthorizationContext\x12\n\n\x02id\x18\x02 \x01(\t\"E\n\x15\x44\x65leteAccountResponse\x12,\n\x11standard_response\x18\x02 \x01(\x0b\x32\x11.StandardResponse\"r\n\x0cLoginRequest\x12\x34\n\x15\x61uthorization_context\x18\x01 \x01(\x0b\x32\x15.AuthorizationContext\x12\x1a\n\x12preferred_username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"\xae\x01\n\rLoginResponse\x12\x34\n\x15\x61uthorization_context\x18\x01 \x01(\x0b\x32\x15.AuthorizationContext\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\x12,\n\x11standard_response\x18\x03 \x01(\x0b\x32\x11.StandardResponse\x12\"\n\x07\x61\x63\x63ount\x18\x04 \x01(\x0b\x32\x11.identity.Account\"Q\n\rLogoutRequest\x12\x34\n\x15\x61uthorization_context\x18\x01 \x01(\x0b\x32\x15.AuthorizationContext\x12\n\n\x02id\x18\x02 \x01(\t\"b\n\x0eLogoutResponse\x12,\n\x11standard_response\x18\x01 \x01(\x0b\x32\x11.StandardResponse\x12\"\n\x07\x61\x63\x63ount\x18\x02 \x01(\x0b\x32\x11.identity.Account\"n\n\x13RefreshTokenRequest\x12\x34\n\x15\x61uthorization_context\x18\x01 \x01(\x0b\x32\x15.AuthorizationContext\x12\n\n\x02id\x18\x02 \x01(\t\x12\x15\n\rrefresh_token\x18\x03 \x01(\t\"[\n\x14RefreshTokenResponse\x12\x15\n\rrefresh_token\x18\x01 \x01(\t\x12,\n\x11standard_response\x18\x02 \x01(\x0b\x32\x11.StandardResponse\"\x85\x01\n\x15\x43hangePasswordRequest\x12\x34\n\x15\x61uthorization_context\x18\x01 \x01(\x0b\x32\x15.AuthorizationContext\x12\n\n\x02id\x18\x02 \x01(\t\x12\x14\n\x0cold_password\x18\x03 \x01(\t\x12\x14\n\x0cnew_password\x18\x04 \x01(\t\"\x81\x01\n\x16\x43hangePasswordResponse\x12,\n\x11standard_response\x18\x01 \x01(\x0b\x32\x11.StandardResponse\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\x12\"\n\x07\x61\x63\x63ount\x18\x03 \x01(\x0b\x32\x11.identity.Account2\xed\x04\n\x0e\x41\x63\x63ountService\x12P\n\rCreateAccount\x12\x1e.identity.CreateAccountRequest\x1a\x1f.identity.CreateAccountResponse\x12P\n\rUpdateAccount\x12\x1e.identity.UpdateAccountRequest\x1a\x1f.identity.UpdateAccountResponse\x12J\n\x0bReadAccount\x12\x1c.identity.ReadAccountRequest\x1a\x1d.identity.ReadAccountResponse\x12P\n\rDeleteAccount\x12\x1e.identity.DeleteAccountRequest\x1a\x1f.identity.DeleteAccountResponse\x12\x38\n\x05Login\x12\x16.identity.LoginRequest\x1a\x17.identity.LoginResponse\x12;\n\x06Logout\x12\x17.identity.LogoutRequest\x1a\x18.identity.LogoutResponse\x12M\n\x0cRefreshToken\x12\x1d.identity.RefreshTokenRequest\x1a\x1e.identity.RefreshTokenResponse\x12S\n\x0e\x43hangePassword\x12\x1f.identity.ChangePasswordRequest\x1a .identity.ChangePasswordResponseB.\n\x15\x63om.apexnova.identityB\x13\x41\x63\x63ountServiceProtoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'apexnova.identity.account.account_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.apexnova.identityB\023AccountServiceProtoP\001'
  _globals['_READACCOUNTREQUEST']._serialized_start=175
  _globals['_READACCOUNTREQUEST']._serialized_end=261
  _globals['_READACCOUNTRESPONSE']._serialized_start=263
  _globals['_READACCOUNTRESPONSE']._serialized_end=366
  _globals['_CREATEACCOUNTREQUEST']._serialized_start=369
  _globals['_CREATEACCOUNTREQUEST']._serialized_end=656
  _globals['_CREATEACCOUNTRESPONSE']._serialized_start=659
  _globals['_CREATEACCOUNTRESPONSE']._serialized_end=787
  _globals['_UPDATEACCOUNTREQUEST']._serialized_start=790
  _globals['_UPDATEACCOUNTREQUEST']._serialized_end=1043
  _globals['_UPDATEACCOUNTRESPONSE']._serialized_start=1045
  _globals['_UPDATEACCOUNTRESPONSE']._serialized_end=1150
  _globals['_DELETEACCOUNTREQUEST']._serialized_start=1152
  _globals['_DELETEACCOUNTREQUEST']._serialized_end=1240
  _globals['_DELETEACCOUNTRESPONSE']._serialized_start=1242
  _globals['_DELETEACCOUNTRESPONSE']._serialized_end=1311
  _globals['_LOGINREQUEST']._serialized_start=1313
  _globals['_LOGINREQUEST']._serialized_end=1427
  _globals['_LOGINRESPONSE']._serialized_start=1430
  _globals['_LOGINRESPONSE']._serialized_end=1604
  _globals['_LOGOUTREQUEST']._serialized_start=1606
  _globals['_LOGOUTREQUEST']._serialized_end=1687
  _globals['_LOGOUTRESPONSE']._serialized_start=1689
  _globals['_LOGOUTRESPONSE']._serialized_end=1787
  _globals['_REFRESHTOKENREQUEST']._serialized_start=1789
  _globals['_REFRESHTOKENREQUEST']._serialized_end=1899
  _globals['_REFRESHTOKENRESPONSE']._serialized_start=1901
  _globals['_REFRESHTOKENRESPONSE']._serialized_end=1992
  _globals['_CHANGEPASSWORDREQUEST']._serialized_start=1995
  _globals['_CHANGEPASSWORDREQUEST']._serialized_end=2128
  _globals['_CHANGEPASSWORDRESPONSE']._serialized_start=2131
  _globals['_CHANGEPASSWORDRESPONSE']._serialized_end=2260
  _globals['_ACCOUNTSERVICE']._serialized_start=2263
  _globals['_ACCOUNTSERVICE']._serialized_end=2884
# @@protoc_insertion_point(module_scope)
