# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: apexnova/identity/account/account.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'apexnova/identity/account/account.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'apexnova/identity/account/account.proto\x12\x08identity\"I\n\x0eThirdPartyInfo\x12\x13\n\x0bprovider_id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x13\n\x0bprofile_url\x18\x03 \x01(\t\"\xc6\x02\n\x07\x41\x63\x63ount\x12\n\n\x02id\x18\x01 \x01(\t\x12#\n\x04type\x18\x02 \x01(\x0e\x32\x15.identity.AccountType\x12\'\n\x06status\x18\x03 \x01(\x0e\x32\x17.identity.AccountStatus\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\r\n\x05phone\x18\x05 \x01(\t\x12(\n\x06google\x18\x06 \x01(\x0b\x32\x18.identity.ThirdPartyInfo\x12\'\n\x05\x61pple\x18\x07 \x01(\x0b\x32\x18.identity.ThirdPartyInfo\x12+\n\tmicrosoft\x18\x08 \x01(\x0b\x32\x18.identity.ThirdPartyInfo\x12\x12\n\nowner_name\x18\t \x01(\t\x12\x1a\n\x12preferred_username\x18\n \x01(\t\x12\x13\n\x0bpicture_url\x18\x0b \x01(\t*a\n\x0b\x41\x63\x63ountType\x12\x1c\n\x18\x41\x43\x43OUNT_TYPE_UNSPECIFIED\x10\x00\x12\x19\n\x15\x41\x43\x43OUNT_TYPE_PERSONAL\x10\x01\x12\x19\n\x15\x41\x43\x43OUNT_TYPE_BUSINESS\x10\x02*\x85\x01\n\rAccountStatus\x12\x1e\n\x1a\x41\x43\x43OUNT_STATUS_UNSPECIFIED\x10\x00\x12\x19\n\x15\x41\x43\x43OUNT_STATUS_ACTIVE\x10\x01\x12\x1b\n\x17\x41\x43\x43OUNT_STATUS_INACTIVE\x10\x02\x12\x1c\n\x18\x41\x43\x43OUNT_STATUS_SUSPENDED\x10\x03\x42\'\n\x15\x63om.apexnova.identityB\x0c\x41\x63\x63ountProtoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'apexnova.identity.account.account_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.apexnova.identityB\014AccountProtoP\001'
  _globals['_ACCOUNTTYPE']._serialized_start=457
  _globals['_ACCOUNTTYPE']._serialized_end=554
  _globals['_ACCOUNTSTATUS']._serialized_start=557
  _globals['_ACCOUNTSTATUS']._serialized_end=690
  _globals['_THIRDPARTYINFO']._serialized_start=53
  _globals['_THIRDPARTYINFO']._serialized_end=126
  _globals['_ACCOUNT']._serialized_start=129
  _globals['_ACCOUNT']._serialized_end=455
# @@protoc_insertion_point(module_scope)
