# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: apexnova/entity/entity.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'apexnova/entity/entity.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x61pexnova/entity/entity.proto\x12\x06\x65ntity\"\xb1\x01\n\x06\x45ntity\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x0c\n\x04tags\x18\x06 \x03(\t\x12\x18\n\x10\x62lob_storage_url\x18\x08 \x01(\t\x12\x15\n\rlast_modified\x18\x0c \x01(\t\x12\x13\n\x0b\x61\x63\x63\x65ss_tier\x18\x0e \x01(\t\x12$\n\x06status\x18\x0f \x01(\x0e\x32\x14.entity.EntityStatus*\x80\x01\n\x0c\x45ntityStatus\x12\x1d\n\x19\x45NTITY_STATUS_UNSPECIFIED\x10\x00\x12\x19\n\x15\x45NTITY_STATUS_CREATED\x10\x01\x12\x1a\n\x16\x45NTITY_STATUS_UPLOADED\x10\x02\x12\x1a\n\x16\x45NTITY_STATUS_VERIFIED\x10\x03\x42$\n\x13\x63om.apexnova.entityB\x0b\x45ntityProtoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'apexnova.entity.entity_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.apexnova.entityB\013EntityProtoP\001'
  _globals['_ENTITYSTATUS']._serialized_start=221
  _globals['_ENTITYSTATUS']._serialized_end=349
  _globals['_ENTITY']._serialized_start=41
  _globals['_ENTITY']._serialized_end=218
# @@protoc_insertion_point(module_scope)
