# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: apexnova/stub/authorization_context.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'apexnova/stub/authorization_context.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)apexnova/stub/authorization_context.proto\"\x93\x02\n\x14\x41uthorizationContext\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x05roles\x18\x02 \x03(\x0e\x32\x05.Role\x12\x15\n\x05\x61\x63tor\x18\x03 \x01(\x0e\x32\x06.Actor\x12\x12\n\nip_address\x18\x04 \x01(\t\x12\x14\n\x0crequest_time\x18\x05 \x01(\x03\x12\x17\n\x06\x64\x65vice\x18\x06 \x01(\x0e\x32\x07.Device\x12\x1b\n\x08location\x18\x07 \x01(\x0e\x32\t.Location\x12\x1e\n\nuser_agent\x18\x08 \x01(\x0e\x32\n.UserAgent\x12\x13\n\x04tier\x18\t \x01(\x0e\x32\x05.Tier\x12\x19\n\x11\x63lient_request_id\x18\n \x01(\t\x12\x12\n\naccount_id\x18\x0b \x01(\t*K\n\x04Role\x12\x14\n\x10ROLE_UNSPECIFIED\x10\x00\x12\x0e\n\nROLE_ADMIN\x10\x01\x12\r\n\tROLE_USER\x10\x02\x12\x0e\n\nROLE_GUEST\x10\x03*E\n\x05\x41\x63tor\x12\x15\n\x11\x41\x43TOR_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x41\x43TOR_END_USER\x10\x01\x12\x11\n\rACTOR_SERVICE\x10\x02*\xba\x02\n\x06\x44\x65vice\x12\x16\n\x12\x44\x45VICE_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x44\x45VICE_DESKTOP_WINDOWS\x10\x01\x12\x16\n\x12\x44\x45VICE_DESKTOP_MAC\x10\x02\x12\x19\n\x15\x44\x45VICE_MOBILE_ANDROID\x10\x03\x12\x15\n\x11\x44\x45VICE_MOBILE_IOS\x10\x04\x12\x19\n\x15\x44\x45VICE_TABLET_ANDROID\x10\x05\x12\x15\n\x11\x44\x45VICE_TABLET_IOS\x10\x06\x12\x13\n\x0f\x44\x45VICE_SMART_TV\x10\x07\x12\x13\n\x0f\x44\x45VICE_WEARABLE\x10\x08\x12\x16\n\x12\x44\x45VICE_SET_TOP_BOX\x10\t\x12\x17\n\x13\x44\x45VICE_GAME_CONSOLE\x10\n\x12\x13\n\x0f\x44\x45VICE_E_READER\x10\x0b\x12\x10\n\x0c\x44\x45VICE_OTHER\x10\x0c*\xef\x01\n\x08Location\x12\x18\n\x14LOCATION_UNSPECIFIED\x10\x00\x12\x10\n\x0cLOCATION_USA\x10\x01\x12\x13\n\x0fLOCATION_CANADA\x10\x02\x12\x0f\n\x0bLOCATION_UK\x10\x03\x12\x14\n\x10LOCATION_GERMANY\x10\x04\x12\x13\n\x0fLOCATION_FRANCE\x10\x05\x12\x12\n\x0eLOCATION_INDIA\x10\x06\x12\x12\n\x0eLOCATION_CHINA\x10\x07\x12\x12\n\x0eLOCATION_JAPAN\x10\x08\x12\x16\n\x12LOCATION_AUSTRALIA\x10\t\x12\x12\n\x0eLOCATION_OTHER\x10\n*\x99\x04\n\tUserAgent\x12\x1a\n\x16USER_AGENT_UNSPECIFIED\x10\x00\x12\x1d\n\x19USER_AGENT_BROWSER_CHROME\x10\x01\x12\x1e\n\x1aUSER_AGENT_BROWSER_FIREFOX\x10\x02\x12\x1d\n\x19USER_AGENT_BROWSER_SAFARI\x10\x03\x12\x1b\n\x17USER_AGENT_BROWSER_EDGE\x10\x04\x12\x1c\n\x18USER_AGENT_BROWSER_OPERA\x10\x05\x12!\n\x1dUSER_AGENT_MOBILE_APP_ANDROID\x10\x06\x12\x1d\n\x19USER_AGENT_MOBILE_APP_IOS\x10\x07\x12\x19\n\x15USER_AGENT_API_CLIENT\x10\x08\x12\x1b\n\x17USER_AGENT_SMART_TV_APP\x10\t\x12\x1b\n\x17USER_AGENT_WEARABLE_APP\x10\n\x12\x1e\n\x1aUSER_AGENT_SET_TOP_BOX_APP\x10\x0b\x12\x1f\n\x1bUSER_AGENT_GAME_CONSOLE_APP\x10\x0c\x12\x1b\n\x17USER_AGENT_E_READER_APP\x10\r\x12\x19\n\x15USER_AGENT_BOT_GOOGLE\x10\x0e\x12\x17\n\x13USER_AGENT_BOT_BING\x10\x0f\x12\x18\n\x14USER_AGENT_BOT_YAHOO\x10\x10\x12\x14\n\x10USER_AGENT_OTHER\x10\x11*V\n\x04Tier\x12\x14\n\x10TIER_UNSPECIFIED\x10\x00\x12\x13\n\x0fTIER_PRODUCTION\x10\x01\x12\x14\n\x10TIER_DEVELOPMENT\x10\x02\x12\r\n\tTIER_TEST\x10\x03\x42\x30\n\x11\x63om.apexnova.stubB\x19\x41uthorizationContextProtoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'apexnova.stub.authorization_context_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\021com.apexnova.stubB\031AuthorizationContextProtoP\001'
  _globals['_ROLE']._serialized_start=323
  _globals['_ROLE']._serialized_end=398
  _globals['_ACTOR']._serialized_start=400
  _globals['_ACTOR']._serialized_end=469
  _globals['_DEVICE']._serialized_start=472
  _globals['_DEVICE']._serialized_end=786
  _globals['_LOCATION']._serialized_start=789
  _globals['_LOCATION']._serialized_end=1028
  _globals['_USERAGENT']._serialized_start=1031
  _globals['_USERAGENT']._serialized_end=1568
  _globals['_TIER']._serialized_start=1570
  _globals['_TIER']._serialized_end=1656
  _globals['_AUTHORIZATIONCONTEXT']._serialized_start=46
  _globals['_AUTHORIZATIONCONTEXT']._serialized_end=321
# @@protoc_insertion_point(module_scope)
